@@ -1,8 +1,8 @@
 <?php
 /**
- * $Horde: kronolith/calendars.php,v 1.46.2.3 2005/01/04 04:44:05 chuck Exp $
+ * $Horde: kronolith/calendars.php,v 1.46.2.5 2006/01/01 21:29:02 jan Exp $
  *
- * Copyright 2002-2005 Joel Vandal <jvandal@infoteck.qc.ca>
+ * Copyright 2002-2006 Joel Vandal <jvandal@infoteck.qc.ca>
  *
  * See the enclosed file COPYING for license information (GPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
@@ -112,11 +112,20 @@ case 'delete':
     exit;
 }
 
-// Personal Calendars.
-$personal_calendars = Kronolith::listCalendars(true);
+$remote_calendars = unserialize($prefs->getValue('remote_cals'));
+$current_user = Auth::getAuth();
+$my_calendars = array();
+$shared_calendars = array();
+foreach (Kronolith::listCalendars() as $id => $cal) {
+    if ($cal->get('owner') == $current_user) {
+        $my_calendars[$id] = $cal;
+    } else {
+        $shared_calendars[$id] = $cal;
+    }
+}
 
 Horde::addScriptFile('popup.js', 'horde', true);
-$title = _("Calendars");
+$title = _("My Calendars");
 require KRONOLITH_TEMPLATES . '/common-header.inc';
 require KRONOLITH_TEMPLATES . '/menu.inc';
 require KRONOLITH_TEMPLATES . '/calendars/calendars.inc';
