@@ -3,7 +3,7 @@
  * The Kronolith_Driver_sql:: class implements the Kronolith_Driver
  * API for a SQL backend.
  *
- * $Horde: kronolith/lib/Driver/sql.php,v 1.136.2.20 2006/05/03 21:54:29 jan Exp $
+ * $Horde: kronolith/lib/Driver/sql.php,v 1.136.2.25 2006/10/11 13:20:29 jan Exp $
  *
  * @author  Luc Saillard <luc.saillard@fr.alcove.com>
  * @author  Chuck Hagenbuch <chuck@horde.org>
@@ -81,6 +81,8 @@ class Kronolith_Driver_sql extends Kronolith_Driver {
 
     function search($query)
     {
+        require_once 'Horde/SQL.php';
+
         // Build SQL conditions based on the query string.
         $cond = '((';
         $values = array();
@@ -374,7 +376,7 @@ class Kronolith_Driver_sql extends Kronolith_Driver {
         }
     }
 
-    function &getByUID($uid)
+    function &getByUID($uid, $getAll = false)
     {
         $this->_connect();
 
@@ -392,19 +394,52 @@ class Kronolith_Driver_sql extends Kronolith_Driver {
                                   Auth::getAuth(), $query),
                           __FILE__, __LINE__, PEAR_LOG_DEBUG);
 
-        $event = &$this->_db->getRow($query, $values, DB_FETCHMODE_ASSOC);
-        if (is_a($event, 'PEAR_Error')) {
-            Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
-            return $event;
+        $events = $this->_db->getAll($query, $values, DB_FETCHMODE_ASSOC);
+        if (is_a($events, 'PEAR_Error')) {
+            Horde::logMessage($events, __FILE__, __LINE__, PEAR_LOG_ERR);
+            return $events;
         }
-
-        if ($event) {
-            $this->open($event['calendar_id']);
-            $this->_cache[$this->_calendar][$event['event_id']] = &new Kronolith_Event_sql($this, $event);
-            return $this->_cache[$this->_calendar][$event['event_id']];
-        } else {
+        if (!count($events)) {
             return PEAR::raiseError($uid . ' not found');
         }
+
+        $eventArray = array();
+        foreach ($events as $event) {
+            $this->open($event['calendar_id']);
+            $this->_cache[$this->_calendar][$event['event_id']] = &new Kronolith_Event_sql($this, $event);
+            $eventArray[] = &$this->_cache[$this->_calendar][$event['event_id']];
+        }
+
+        if ($getAll) {
+            return $eventArray;
+        }
+
+        /* First try the user's own calendars. */
+        $ownerCalendars = Kronolith::listCalendars(true, PERMS_READ);
+        $event = null;
+        foreach ($eventArray as $ev) {
+            if (isset($ownerCalendars[$ev->getCalendar()])) {
+                $event = $ev;
+                break;
+            }
+        }
+
+        /* If not successful, try all calendars the user has access too. */
+        if (empty($event)) {
+            $readableCalendars = Kronolith::listCalendars(false, PERMS_READ);
+            foreach ($eventArray as $ev) {
+                if (isset($readableCalendars[$ev->getCalendar()])) {
+                    $event = $ev;
+                    break;
+                }
+            }
+        }
+
+        if (empty($event)) {
+            $event = $eventArray[0];
+        }
+
+        return $event;
     }
 
     /**
@@ -729,7 +764,10 @@ class Kronolith_Event_sql extends Kronolith_Event {
 
         if (isset($SQLEvent['event_recurenddate'])) {
             $this->recurEnd = &new Horde_Date();
-            list($this->recurEnd->year, $this->recurEnd->month, $this->recurEnd->mday, $this->recurEnd->hour, $this->recurEnd->min, $this->recurEnd->sec) = sscanf($SQLEvent['event_recurenddate'], '%04d-%02d-%02d %02d:%02d:%02d');
+            list($this->recurEnd->year, $this->recurEnd->month, $this->recurEnd->mday) = sscanf($SQLEvent['event_recurenddate'], '%04d-%02d-%02d 00:00:00');
+            $this->recurEnd->hour = 23;
+            $this->recurEnd->min = 59;
+            $this->recurEnd->sec = 59;
         }
 
         $this->title = $driver->convertFromDriver($SQLEvent['event_title']);
@@ -749,7 +787,7 @@ class Kronolith_Event_sql extends Kronolith_Event {
             $this->status = $SQLEvent['event_status'];
         }
         if (isset($SQLEvent['event_attendees'])) {
-            $this->attendees = unserialize($driver->convertFromDriver($SQLEvent['event_attendees']));
+            $this->attendees = array_change_key_case(unserialize($driver->convertFromDriver($SQLEvent['event_attendees'])));
         }
         if (isset($SQLEvent['event_keywords'])) {
             $this->keywords = explode(',', $driver->convertFromDriver($SQLEvent['event_keywords']));
@@ -807,7 +845,7 @@ class Kronolith_Event_sql extends Kronolith_Event {
         $this->_properties['event_recurtype'] = $recur;
         if ($recur != KRONOLITH_RECUR_NONE) {
             $this->_properties['event_recurinterval'] = $this->getRecurInterval();
-            $this->_properties['event_recurenddate'] = sprintf('%04d%02d%02d', $recur_end[0],
+            $this->_properties['event_recurenddate'] = sprintf('%04d-%02d-%02d', $recur_end[0],
                                                                $recur_end[1], $recur_end[2]);
 
             switch ($recur) {
